# -*- coding: utf-8 -*-
# Generated by Django 1.11.20 on 2019-05-28 18:18
from __future__ import unicode_literals

from django.db import migrations

GROUP_DATA = [
    {
        'name': 'executives',
        'description': ('"Executive users" who can expose and hide events, '
            'superevents, and log messages. This is a holdover from O1/O2 and '
            'should be deleted in favor of the "access_managers" group once '
            'the permissions for the events app can be reworked to be more '
            'like the superevents app.'),
    },
    {
        'name': 'Communities:LSCVirgoLIGOGroupMembers',
        'ldap_name': 'Communities:LSCVirgoLIGOGroupMembers',
        'new_name': 'internal_users',
        'description': 'Internal users (LIGO, Virgo, and soon, KAGRA).',
    },
    {
        'name': 'gw-astronomy:LV-EM',
        'ldap_name': 'gw-astronomy:LV-EM',
        'new_name': 'lvem_users',
        'description': ('LV-EM group; not sure why this exists exactly, but '
            'these users have been allowed to see MDC events historically.'),
    },
    {
        'name': 'public_users',
        'tag_name': 'public',
        'description': ('Public group, used for unauthenticated users to map '
            'into the django-guardian AnonymousUser account to allow '
            'object permissions.'),
    },
    {
        'name': 'h1_control_room',
        'description': ('Users in the Hanford (H1) control room. Membership '
            'in this group is set on a per-request basis by some middleware '
            'which checks the user\'s IP versus a specific IP in the Django '
            'settings. This group may not be used going forward since '
            'operator signoffs do not appear to be used in O3.'),
    },
    {
        'name': 'l1_control_room',
        'description': ('Users in the Livingston (L1) control room. Membership'
            ' in this group is set on a per-request basis by some middleware '
            'which checks the user\'s IP versus a specific IP in the Django '
            'settings. This group may not be used going forward since '
            'operator signoffs do not appear to be used in O3.'),
    },
    {
        'name': 'v1_control_room',
        'description': ('Users in the Virgo (V1) control room. Membership '
            'in this group is set on a per-request basis by some middleware '
            'which checks the user\'s IP versus a specific IP in the Django '
            'settings. This group may not be used going forward since '
            'operator signoffs do not appear to be used in O3.'),
    },
    {
        'name': 'gw-astronomy:LV-EM:Observers',
        'ldap_name': 'gw-astronomy:LV-EM:Observers',
        'new_name': 'lvem_observers',
        'tag_name': 'lvem',
        'description': ('LV-EM observers group. This is the primary group '
            'used for allowing access to LV-EM members.'),
    },
    {
        'name': 'em_advocates',
        'ldap_name': 'Communities:LVC:GraceDB:GraceDBAdvocates',
        'description': ('EM follow-up advocates; responsible for managing '
            'rapid response to new candidate events/superevents and '
            'performing advocate signoffs.'),
    },
    {
        'name': 'superevent_managers',
        'description': ('Users responsible for creating and updating both '
            'production and MDC superevents.'),
    },
    {
        'name': 'access_managers',
        'description': ('Users responsible for allowing non-internal access '
            'to superevents and log messages. At present, they have no '
            'ability to modify event permissions, although this should '
            'change in the future when permissions are consolidated.'),
    },
    {
        'name': 'priority_users',
        'description': ('Users allowed to access the priority API (which '
            'does not exist at present [June 2019]).'),
    },
    {
        'name': 'raven_users',
        'description': ('Users in charge of managing the RAVEN pipeline. '
            'Have permission to upload external events.'),
    },
]


def create_authgroups(apps, schema_editor):
    DjangoGroup = apps.get_model('auth', 'Group')
    AuthGroup = apps.get_model('ligoauth', 'AuthGroup')
    Tag = apps.get_model('events', 'Tag')

    # Create AuthGroup instances
    for group in GROUP_DATA:
        g, created = DjangoGroup.objects.get_or_create(name=group['name'])
        ag = AuthGroup(group_ptr=g)
        ag.description = group['description']

        # Update from base class
        ag.__dict__.update(g.__dict__)

        # Save
        ag.save()

        # Add optional extras and save
        if 'new_name' in group:
            ag.name = group['new_name']
        if 'ldap_name' in group:
            ag.ldap_name = group['ldap_name']
        if 'tag_name' in group:
            tag, _ = Tag.objects.get_or_create(name=group['tag_name'])
            ag.tag = tag
        ag.save()


def delete_authgroups(apps, schema_editor):
    AuthGroup = apps.get_model('ligoauth', 'AuthGroup')

    # Loop over groups and delete AuthGroup
    for group in GROUP_DATA:
        # Get AuthGroup
        group_name = group['name']
        if 'new_name' in group:
            group_name = group['new_name']
        ag = AuthGroup.objects.get(name=group_name)

        # Reset name if needed
        if 'new_name' in group:
            ag.name = group['name']
            ag.save()

        # Delete AuthGroup and keep DjangoGroup base class
        ag.delete(keep_parents=True)


class Migration(migrations.Migration):

    dependencies = [
        ('ligoauth', '0037_authgroup'),
    ]

    operations = [
        migrations.RunPython(create_authgroups, delete_authgroups),
    ]
