# Generated by Alexander Pace (2022-08-29)
# A migration that makes a new account, and then allows that account 
# with some other users to upload to a pipeline:

from django.db import migrations, models
from django.conf import settings


# List of robot accounts to create:
ROBOTS = [
        {
            'username' : 'hwinj',
            'first_name' : '',
            'last_name' : 'HW-INJ',  # Note that the last_name acts as a display
            'email' : 'siddharth.soni@ligo.org',
            'dns' : [
                "/DC=org/DC=cilogon/C=US/O=LIGO/OU=Robots/CN=siddharth-macbook-pro/CN=hwink/CN=Siddharth Soni/CN=UID:siddharth.soni.robot",
            ]
        },
]

UPLOADERS = ['hwinj',
             'siddharth.soni@ligo.org',]

def create_robots(apps, schema_editor):
    User = apps.get_model('auth', 'User')
    X509Cert = apps.get_model('ligoauth', 'X509Cert')
    AuthGroup = apps.get_model('ligoauth', 'AuthGroup')
    lvc_group = AuthGroup.objects.get(name=settings.LVC_GROUP)
    robot_group = AuthGroup.objects.get(name='robot_accounts')

    for entry in ROBOTS:
        user, created = User.objects.get_or_create(username=entry['username'])
        if created:
            user.first_name = entry['first_name']
            user.last_name = entry['last_name']
            user.email = entry['email']
            user.is_active = True
            user.is_staff = False
            user.is_superuser = False
            user.save()

        # Create the cert objects and link them to our user.
        for dn in entry['dns']:
            cert, created = X509Cert.objects.get_or_create(subject=dn,
                user=user)

        # Add our user to the LVC group. This permission is required to
        # do most things, but may *NOT* always be appropriate. It may
        # also be necessary to give the robotic user permission to populate
        # a particular pipeline.
        lvc_group.user_set.add(user)

        # Add user to robot accounts
        robot_group.user_set.add(user)

def delete_robots(apps, schema_editor):
    User = apps.get_model('auth', 'User')
    X509Cert = apps.get_model('ligoauth', 'X509Cert')

    for entry in ROBOTS:
        for dn in entry['dns']:
            X509Cert.objects.get(subject=dn).delete()
        User.objects.get(username=entry['username']).delete()

def add_permissions(apps, schema_editor):
    User = apps.get_model('auth', 'User')
    Permission = apps.get_model('auth', 'Permission')
    UserObjectPermission = apps.get_model('guardian', 'UserObjectPermission')
    Pipeline = apps.get_model('events', 'Pipeline')
    ContentType = apps.get_model('contenttypes', 'ContentType')

    perm = Permission.objects.get(codename='populate_pipeline')
    ctype = ContentType.objects.get_for_model(Pipeline)

    pipeline, created = Pipeline.objects.get_or_create(name='HardwareInjection')
 
    # Loop over users
    for username in UPLOADERS:
 
        # Robot users should have been already created by ligoauth 0003,
        # but we have to create human user accounts here
        user, _ = User.objects.get_or_create(username=username)
 
        # Create UserObjectPermission
        uop, uop_created = UserObjectPermission.objects.get_or_create(
            user=user, permission=perm, content_type=ctype,
            object_pk=pipeline.id)

def remove_permissions(apps, schema_editor):
    pass


class Migration(migrations.Migration):

    dependencies = [
        ('ligoauth', '0085_bulk_account_update'),
    ]

    operations = [
        migrations.RunPython(create_robots, delete_robots),
        migrations.RunPython(add_permissions, remove_permissions),
    ]
