# -*- coding: utf-8 -*-
# Generated by alex on 2023-04-20
# Fixes:
# https://git.ligo.org/computing/helpdesk/-/issues/3793

from __future__ import unicode_literals

from django.db import migrations


mly_account = 'mly.robot'
kyle_w = 'kyle.willetts.robot'

new_certs = ['/DC=org/DC=cilogon/C=US/O=LIGO/OU=Robots/CN=mly.ligo.org/CN=mly/CN=Vasileios Skliris/CN=UID:vasileios.skliris.robot',
]


def add_cert(apps, schema_editor):
    RobotUser = apps.get_model('auth', 'User')
    X509Cert = apps.get_model('ligoauth', 'X509Cert')

    # Get user
    user = RobotUser.objects.get(username=mly_account)

    # delete old certificates:
    for k in user.x509cert_set.filter(subject__contains=kyle_w):
        k.delete()

    # Create new certificates
    for dn in new_certs:
        new_cert, created = X509Cert.objects.get_or_create(subject=dn,
                user=user)
        if created:
            user.x509cert_set.add(new_cert)


def delete_cert(apps, schema_editor):
    RobotUser = apps.get_model('auth', 'User')
    X509Cert = apps.get_model('ligoauth', 'X509Cert')

    # Get user
    user = RobotUser.objects.get(username=mly_account)

    # Delete new certificates
    for cert in new_certs:
        cert = user.x509cert_set.get(subject=cert)
        cert.delete()


class Migration(migrations.Migration):

    # make it dependent on the old mly cert
    dependencies = [
        ('ligoauth', '0087_rrt_and_alert_groups'),
    ]

    operations = [
        migrations.RunPython(add_cert, delete_cert),
    ]
