# -*- coding: utf-8 -*-
# Generated by Django 1.11.20 on 2019-05-28 18:18
from __future__ import unicode_literals

from django.db import migrations

GROUP_DATA = [
    {
        'name': 'catalog_managers',
        'description': ('Catalog Managers who can create and delete GWTC objects.'),
    },
]


def create_authgroups(apps, schema_editor):
    DjangoGroup = apps.get_model('auth', 'Group')
    AuthGroup = apps.get_model('ligoauth', 'AuthGroup')
    Tag = apps.get_model('events', 'Tag')

    # Create AuthGroup instances
    for group in GROUP_DATA:
        g, created = DjangoGroup.objects.get_or_create(name=group['name'])
        ag = AuthGroup(group_ptr=g)
        ag.description = group['description']

        # Update from base class
        ag.__dict__.update(g.__dict__)

        # Save
        ag.save()

        # Add optional extras and save
        if 'new_name' in group:
            ag.name = group['new_name']
        if 'ldap_name' in group:
            ag.ldap_name = group['ldap_name']
        if 'tag_name' in group:
            tag, _ = Tag.objects.get_or_create(name=group['tag_name'])
            ag.tag = tag
        ag.save()


def delete_authgroups(apps, schema_editor):
    AuthGroup = apps.get_model('ligoauth', 'AuthGroup')

    # Loop over groups and delete AuthGroup
    for group in GROUP_DATA:
        # Get AuthGroup
        group_name = group['name']
        if 'new_name' in group:
            group_name = group['new_name']
        ag = AuthGroup.objects.get(name=group_name)

        # Reset name if needed
        if 'new_name' in group:
            ag.name = group['name']
            ag.save()

        # Delete AuthGroup and keep DjangoGroup base class
        ag.delete(keep_parents=True)


class Migration(migrations.Migration):

    dependencies = [
        ('ligoauth', '0095_another_gstlalcbc_cert'),
        ('auth', '0030_create_gwtc_groups'),
    ]

    operations = [
        migrations.RunPython(create_authgroups, delete_authgroups),
    ]
