# Generated by Alexander Pace (2024-01-11)
# This migration creates the gstlalcbc_nemo account, removes the 
# existing x509 cert from gstlalcbc, creates a cert for gstlalcbc_nemo, 
# and then adds them to the uploaders list. 

from django.db import migrations, models
from django.conf import settings


# List of robot accounts to create:
ROBOT = {
            'username' : 'gstlalcbc_nemo',
            'first_name' : '',
            'last_name' : 'GstLal CBC at NEMO',  # Note that the last_name acts as a display
            'email' : 'amanda.baylor@LIGO.org',
            'dn' : '/DC=org/DC=cilogon/C=US/O=LIGO/OU=Robots/CN=submit.nemo.uwm.edu/CN=gstlalcbc_online_nemo_robot/CN=Amanda Baylor/CN=UID:amanda.baylor.robot',
        }

UPLOADERS = ['gstlalcbc_nemo']

def create_robots(apps, schema_editor):
    User = apps.get_model('auth', 'User')
    X509Cert = apps.get_model('ligoauth', 'X509Cert')
    AuthGroup = apps.get_model('ligoauth', 'AuthGroup')
    lvc_group = AuthGroup.objects.get(name=settings.LVC_GROUP)
    robot_group = AuthGroup.objects.get(name='robot_accounts')

    # First delete gstlalcbc's cert:
    cert, created = X509Cert.objects.get_or_create(subject=ROBOT['dn'])
    if not created:
        cert.delete()

    # Create the gstlalcbc_nemo account:
    user, created = User.objects.get_or_create(username=ROBOT['username'])
    if created:
        user.first_name = ROBOT['first_name']
        user.last_name = ROBOT['last_name']
        user.email = ROBOT['email']
        user.is_active = True
        user.is_staff = False
        user.is_superuser = False
        user.save()

    # Create the cert objects and link them to our user.
    cert, created = X509Cert.objects.get_or_create(subject=ROBOT['dn'],
        user=user)

    # Add our user to the LVC group. This permission is required to
    # do most things, but may *NOT* always be appropriate. It may
    # also be necessary to give the robotic user permission to populate
    # a particular pipeline.
    lvc_group.user_set.add(user)

    # Add user to robot accounts
    robot_group.user_set.add(user)

def delete_robots(apps, schema_editor):
    User = apps.get_model('auth', 'User')
    X509Cert = apps.get_model('ligoauth', 'X509Cert')

    X509Cert.objects.get(subject=ROBOT['dn']).delete()
    User.objects.get(username=ROBOT['username']).delete()

def add_permissions(apps, schema_editor):
    User = apps.get_model('auth', 'User')
    Permission = apps.get_model('auth', 'Permission')
    UserObjectPermission = apps.get_model('guardian', 'UserObjectPermission')
    Pipeline = apps.get_model('events', 'Pipeline')
    ContentType = apps.get_model('contenttypes', 'ContentType')

    perm = Permission.objects.get(codename='populate_pipeline')
    ctype = ContentType.objects.get_for_model(Pipeline)

    pipeline, created = Pipeline.objects.get_or_create(name='gstlal')
 
    # Loop over users
    for username in UPLOADERS:
 
        # Robot users should have been already created by ligoauth 0003,
        # but we have to create human user accounts here
        user, _ = User.objects.get_or_create(username=username)
 
        # Create UserObjectPermission
        uop, uop_created = UserObjectPermission.objects.get_or_create(
            user=user, permission=perm, content_type=ctype,
            object_pk=pipeline.id)

def remove_permissions(apps, schema_editor):
    pass


class Migration(migrations.Migration):

    dependencies = [
        ('ligoauth', '0096_create_cm_authgroup'),
    ]

    operations = [
        migrations.RunPython(create_robots, delete_robots),
        migrations.RunPython(add_permissions, remove_permissions),
    ]
