# -*- coding: utf-8 -*-
# Generated by Django 1.11.5 on 2017-11-02 19:26
from __future__ import unicode_literals

from django.db import migrations

# Gives users table-level permissions which allows the addition and deletion
# of row-level permissions (again, used for exposing/hiding events).

# List of usernames
USERS = [
    'min-a.cho@LIGO.ORG',
    'gracedb.processor',
]

# List of permission codenames
PERMS = [
    'add_groupobjectpermission',
    'delete_groupobjectpermission',
]

def add_perms(apps, schema_editor):
    User = apps.get_model('auth', 'User')
    Permission = apps.get_model('auth', 'Permission')

    for username in USERS:
        user, created = User.objects.get_or_create(username=username)

        # Add permission
        for perm in PERMS:
            perm = Permission.objects.get(codename=perm)
            user.user_permissions.add(perm)

def remove_perms(apps, schema_editor):
    User = apps.get_model('auth', 'User')
    Permission = apps.get_model('auth', 'Permission')

    perm_list = Permission.objects.filter(codename__in=PERMS)
    for username in USERS:
        try:
            user = User.objects.get(username=username)
        except User.DoesNotExist:
            print('User {0} not found to remove permissions, skipping' \
                .format(username))
            break
 
        # Remove perms from user
        for perm in perm_list:
            if perm in user.user_permissions.all():
                user.user_permissions.remove(perm)

class Migration(migrations.Migration):

    dependencies = [
        ('guardian', '0001_initial'),
        ('auth', '0013_add_user_t90_grbevent_permissions'),
        ('ligoauth', '0003_initial_localuser_and_x509cert_data'),
    ]

    operations = [
        migrations.RunPython(add_perms, remove_perms)
    ]
