# -*- coding: utf-8 -*-
# Generated by Django 1.11.14 on 2018-08-02 17:42
from __future__ import unicode_literals

from django.conf import settings
from django.db import migrations
from django.contrib.auth.management import create_permissions


# Group names
EXECS = 'executives'
ACCESS = 'access_managers' # control external access
SUPEREVENTS = 'superevent_managers' # handle superevent creation/update 
H1_CONTROL = 'h1_control_room'
L1_CONTROL = 'l1_control_room'
V1_CONTROL = 'v1_control_room'
EM_ADVOCATES = 'em_advocates'
# Previously, this was teaken from settings.LVC_GROUP, but that value has
# changed. So we have to hard-code it for past migrations
LVC = 'Communities:LSCVirgoLIGOGroupMembers'

SUPEREVENT_PERMS = {
    # Label permissions
    'add_labelling': [LVC],
    'delete_labelling': [LVC],
    # Superevent permissions
    'add_superevent': [SUPEREVENTS],
    'add_mdc_superevent': [SUPEREVENTS],
    'add_test_superevent': [SUPEREVENTS, LVC],
    'change_superevent': [SUPEREVENTS],
    'change_mdc_superevent': [SUPEREVENTS],
    'change_test_superevent': [SUPEREVENTS, LVC],
    'confirm_gw_superevent': [SUPEREVENTS],
    'confirm_gw_mdc_superevent': [SUPEREVENTS],
    'confirm_gw_test_superevent': [SUPEREVENTS, LVC],
    'annotate_superevent': [LVC],
    'view_superevent': [LVC],
    # Superevent access permissions
    'expose_superevent': [EXECS, ACCESS],
    'hide_superevent': [EXECS, ACCESS],
    # VOEvent permissions
    'add_voevent': [LVC],
    # Log permissions
    'view_log': [LVC],
    'tag_log': [LVC],
    'untag_log': [LVC],
    # Log access permissions
    'expose_log': [EXECS, ACCESS],
    'hide_log': [EXECS, ACCESS],
    # Signoff permissions
    'add_signoff': [H1_CONTROL, L1_CONTROL, V1_CONTROL, EM_ADVOCATES],
    'change_signoff': [H1_CONTROL, L1_CONTROL, V1_CONTROL, EM_ADVOCATES],
    'delete_signoff': [H1_CONTROL, L1_CONTROL, V1_CONTROL, EM_ADVOCATES],
    'view_signoff': [LVC],
    'do_H1_signoff': [H1_CONTROL],
    'do_L1_signoff': [L1_CONTROL],
    'do_V1_signoff': [V1_CONTROL],
    'do_adv_signoff': [EM_ADVOCATES],
    # Viewing permissions
    'view_supereventgroupobjectpermission': [LVC],
}


# We have to run this to force the permissions to actually be created.
# Otherwise they are created by a post-migrate signal and it's not possible
# to run all of the migrations in a single command
def create_perms(apps, schema_editor):
    for app_config in apps.get_app_configs():
        app_config.models_module = True
        create_permissions(app_config, apps=apps, verbosity=0)
        app_config.models_module = None


def add_perms(apps, schema_editor):
    Group = apps.get_model('auth', 'Group')
    Permission = apps.get_model('auth', 'Permission')

    # Add superevent permissions to groups
    for codename, group_names in SUPEREVENT_PERMS.items():
        p = Permission.objects.get(codename=codename,
            content_type__app_label='superevents')
        groups = Group.objects.filter(name__in=group_names)
        p.group_set.add(*groups)


def remove_perms(apps, schema_editor):
    Group = apps.get_model('auth', 'Group')
    Permission = apps.get_model('auth', 'Permission')

    # Add permissions to groups
    for codename, group_names in SUPEREVENT_PERMS.items():
        p = Permission.objects.get(codename=codename,
            content_type__app_label='superevents')
        groups = Group.objects.filter(name__in=group_names)
        p.group_set.remove(*groups)


class Migration(migrations.Migration):

    dependencies = [
        ('auth', '0016_create_access_and_superevent_groups'),
        ('superevents', '0001_initial'),
    ]

    operations = [
        migrations.RunPython(create_perms, migrations.RunPython.noop),
        migrations.RunPython(add_perms, remove_perms),
    ]
