# -*- coding: utf-8 -*-
# Generated by Django 1.11.14 on 2018-08-02 17:42
from __future__ import unicode_literals

from django.conf import settings
from django.db import migrations
from django.contrib.auth.management import create_permissions


# Group names
CATALOG = 'catalog_managers' # handle catalog creation 
LVC = 'internal_users'

CATALOG_PERMS = {
    # Superevent permissions
    'add_gwtc_catalog': [CATALOG],
    'delete_gwtc_catalog': [CATALOG],
    # Viewing permissions
    'view_gwtc_cataloggroupobjectpermission': [LVC],
}


# We have to run this to force the permissions to actually be created.
# Otherwise they are created by a post-migrate signal and it's not possible
# to run all of the migrations in a single command
def create_perms(apps, schema_editor):
    for app_config in apps.get_app_configs():
        app_config.models_module = True
        create_permissions(app_config, apps=apps, verbosity=0)
        app_config.models_module = None


def add_perms(apps, schema_editor):
    Group = apps.get_model('auth', 'Group')
    Permission = apps.get_model('auth', 'Permission')

    # Add catalog permissions to groups
    for codename, group_names in CATALOG_PERMS.items():
        p = Permission.objects.get(codename=codename,
            content_type__app_label='gwtc')
        groups = Group.objects.filter(name__in=group_names)
        p.group_set.add(*groups)


def remove_perms(apps, schema_editor):
    Group = apps.get_model('auth', 'Group')
    Permission = apps.get_model('auth', 'Permission')

    # Add permissions to groups
    for codename, group_names in CATALOG_PERMS.items():
        p = Permission.objects.get(codename=codename,
            content_type__app_label='gwtc')
        groups = Group.objects.filter(name__in=group_names)
        p.group_set.remove(*groups)


class Migration(migrations.Migration):

    dependencies = [
        ('auth', '0030_create_gwtc_groups'),
        ('gwtc', '0001_initial'),
    ]

    operations = [
        migrations.RunPython(create_perms, migrations.RunPython.noop),
        migrations.RunPython(add_perms, remove_perms),
    ]
